summaryrefslogtreecommitdiff
path: root/pigs.c
diff options
context:
space:
mode:
authorjoan <joan@abyz.co.uk>2015-04-23 08:58:59 +0100
committerjoan <joan@abyz.co.uk>2015-04-23 08:58:59 +0100
commitb9c55009e05ba1587f794c39ce6f4471bb7383c7 (patch)
tree7fa8b7eb803924154879bd7afa543afb5f76365e /pigs.c
parent9e72562f27d7697831ff90c947f966289eceb202 (diff)
V32-a
Diffstat (limited to 'pigs.c')
-rw-r--r--pigs.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/pigs.c b/pigs.c
index e4e2421..1869164 100644
--- a/pigs.c
+++ b/pigs.c
@@ -26,7 +26,7 @@ For more information, please refer to <http://unlicense.org/>
*/
/*
-This version is for pigpio version 26+
+This version is for pigpio version 32+
*/
#include <stdio.h>
@@ -141,7 +141,7 @@ void print_result(int sock, int rv, cmdCmd_t cmd)
printf(cmdUsage);
break;
- case 6: /* CF2 I2CPK I2CRD I2CRI I2CRK SERR SLR SPIX SPIR */
+ case 6: /* BI2CX CF2 I2CPK I2CRD I2CRI I2CRK SERR SLR SPIX SPIR */
printf("%d", r);
if (r < 0) fatal("ERROR: %s", cmdErrStr(r));
if (r > 0)
@@ -178,6 +178,7 @@ void get_extensions(int sock, int command, int res)
{
switch (command)
{
+ case PI_CMD_BI2CX:
case PI_CMD_CF2:
case PI_CMD_I2CPK:
case PI_CMD_I2CRD: